#  Copyright (C) 2024
#  ABM, Moscow
#
#  UNPUBLISHED PROPRIETARY MATERIAL.
#  ALL RIGHTS RESERVED.
#
#  Authors: Revva Konstantin <k.revva@abm-jsc.ru>

from dataclasses import dataclass


@dataclass
class DefocusSettings:
    rtsp_url: str
    freq_diff_threshold: float
    created_at: float | None = None
    updated_at: float | None = None
